@@ -70,7 +70,8 @@ class Ligand:
                                                         metal=self.metal,
                                                         ligtype=self.geo,
                                                         covrad_metal=covrad_metal,
-                                                        vdwrad_metal=vdwrad_metal
+                                                        vdwrad_metal=vdwrad_metal,
+                                                        debug=debug
                                                         )
         if len(conformers) > 0:
             self.conformerList = conformers
@@ -242,7 +243,6 @@ class Complex:
             self.calculator = CalcExecutor(self.complexMol,parameters=self.parameters,
                                             final_sanity_check=True,relax=single_point,assembly=single_point)
             if self.parameters['debug'] and (not self.calculator.successful):
-                print(e)
                 print('Failed final relaxation. - Retrying with UFF/XTB')
                 print(self.initMol.write_mol2('cool.mol2', writestring=True))
             # Retry with 2 step optimization -> first do UFF -> then do the requested method.
@@ -332,7 +332,8 @@ def gen_aligned_complex(newLigInputDicts,
                                 ligGeo,
                                 ligCharge,
                                 covrad_metal = inputDict['parameters']['covrad_metal'],
-                                vdwrad_metal = inputDict['parameters']['vdwrad_metal']
+                                vdwrad_metal = inputDict['parameters']['vdwrad_metal'],
+                                debug = inputDict['parameters']['debug']
                                 )
             # Store results
             ligandDict[ligid] = ligandClass
@@ -349,12 +350,13 @@ def gen_aligned_complex(newLigInputDicts,
                 newconf, rotscore, sane = io_lig.set_position_align(lig, 
                                                             new_ligcoordList, 
                                                             ligandCopy.corecoordList,
-                                                            covrad_metal=inputDict['parameters']['covrad_metal'])
+                                                            debug=inputDict['parameters']['debug'])
                 if sane:
                     ligconfVals.append(rotscore)
                     newligconfList.append(newconf)
                 else:
-                    print('Conformer sucks!')
+                    if inputDict['parameters']['debug']:
+                        print('Conformer sucks!')
             ligandCopy.conformerList = newligconfList
             ligandCopy.conformerRotScore = ligconfVals
             ligandList.append(copy.deepcopy(ligandCopy))
@@ -684,7 +686,7 @@ def build_complex(inputDict):
         order = np.argsort(xtb_energies)
         for j,i in enumerate(order):
             if tmp_inputDict['parameters']['crest_sampling'] and j == 0: # Run crest sampling on lowest energy isomer!
-                samples,energies = io_crest.crest_conformers(vals[i]['mol2string'],solvent=tmp_inputDict['parameters']['solvent'])
+                samples,energies = io_crest.crest_conformers(vals[i]['mol2string'],solvent=tmp_inputDict['parameters']['xtb_solvent'])
                 vals[i].update({'crest_conformers':samples,'crest_energies':energies})
                 vals[i].update({'energy':min(energies)})
                 tmpmol = io_molecule.convert_io_molecule(vals[i]['mol2string'])
